@@ -34,8 +34,23 @@ setAs("CompadreDB", "data.frame", function(from) {
 
 #' @rdname CompadreDB-Methods
 #' @importFrom tibble as_tibble
+#' @param .rows passed to [tibble::as_tibble()]
+#' @param .name_repair passed to [tibble::as_tibble()]
+#' @param rownames passed to [tibble::as_tibble()]
 #' @export
-as_tibble.CompadreDB <- function(x) as_tibble(x@data)
+as_tibble.CompadreDB <- function(x, 
+                                 .rows = NULL, 
+                                 .name_repair = c("check_unique", "unique", 
+                                                  "universal", "minimal"), 
+                                 rownames = NULL, ...) {
+  as_tibble(
+    x@data, 
+    .rows = .rows, 
+    .name_repair = .name_repair, 
+    rownames = rownames, 
+    ...
+  )  
+}
 
 
 #' @rdname CompadreDB-Methods
